@@ -13,7 +13,7 @@ class Api(object):
     def __del__(self):
         del self.db_client
 
-    def get_node_info(self, ip=None):
+    def get_node_info(self, ip=None, port=5000):
         """
         get node information, if ip is None, will get all node information
         :param ip:
@@ -23,7 +23,7 @@ class Api(object):
         if ip is not None:
             node_list = [node for node in node_list if node["ip"]==ip]
         for index,item in enumerate(node_list):
-            rest_client = RestClient(item["ip"])
+            rest_client = RestClient(item["ip"], port)
             ret = rest_client.state.get_state()
             node_list[index]["state"] = ret["data"][0] if ret["state"] == 1 else "offline"
             node_list[index]["automation"] = ret["data"][4] if ret["state"] == 1 else "None"
@@ -38,23 +38,23 @@ class Api(object):
         """
         self.db_client.env_resource.set_project_name(node_ip, project_name)
 
-    def get_tests_detail(self, ip, numbers=10):
+    def get_tests_detail(self, ip, port=5000, numbers=10):
         """
         get tests of node
         :param ip: node ip address
         :param numbers: numbers of tests want to return
         :return:tests information
         """
-        tests = self.db_client.test_resource.get_tests_by_ip(ip, numbers)
+        tests = self.db_client.test_resource.get_tests_by_ip(ip, port, numbers)
         return tests
 
-    def get_node_usage(self, ip):
+    def get_node_usage(self, ip, port=5000):
         """
         get one node usage rate and running time by ip address
         :param ip:
         :return:
         """
-        node_usage = self.db_client.env_resource.get_node_usage_rate(ip)
+        node_usage = self.db_client.env_resource.get_node_usage_rate(ip, port)
         return node_usage
 
     def search(self, project_name=None, begin_time=None, end_time=None, test_name=None):
