@@ -1,6 +1,7 @@
 # coding=utf-8
 # pylint: disable=import-error, eval-used
-from resources.models.helper import rest_get_call
+import json
+from resources.models.helper import rest_get_call, rest_post_json_call
 
 
 class StateResource(object):
@@ -11,9 +12,18 @@ class StateResource(object):
         self.session = session
         self.time_out = time_out
 
-    def get_state(self):
-        url_ = "http://{0}:{1}/state".format(self.host, self.port)
+    def get_state(self, type_="ALL"):
+        url_ = "http://{0}:{1}/state/{2}".format(self.host, self.port, type_)
         result = rest_get_call(url_, self.session, self.time_out)
         if result["resource"]["data"] is not None and len(result["resource"]["data"]) > 3:
             result["resource"]["data"][3] = eval(result["resource"]["data"][3])
         return result["resource"]
+
+    def update_state(self):
+        url_ = "http://{0}:{1}/state".format(self.host, self.port)
+        data = dict()
+        result = rest_post_json_call(url_, self.session, json.dumps(data), self.time_out)
+        return result["resource"]
+
+
+
